@@ -1,3 +1,4 @@
+from ..helpers import to_int
 from ._utils import *
 from .songs import *
 
@@ -46,6 +47,7 @@ def parse_top_result(data, search_result_types):
 
     if result_type in ["album"]:
         search_result["browseId"] = nav(data, TITLE + NAVIGATION_BROWSE_ID, True)
+        search_result["playlistId"] = nav(data, ["buttons", 0, "buttonRenderer", "command", *WATCH_PID], True)
 
     if result_type in ["playlist"]:
         search_result["playlistId"] = nav(data, MENU_PLAYLIST_ID)
@@ -97,6 +99,8 @@ def parse_search_result(data, search_result_types, result_type, category):
         flex_item = get_flex_column_item(data, 1)["text"]["runs"]
         has_author = len(flex_item) == default_offset + 3
         search_result["itemCount"] = get_item_text(data, 1, default_offset + has_author * 2).split(" ")[0]
+        if search_result["itemCount"] and search_result["itemCount"].isnumeric():
+            search_result["itemCount"] = to_int(search_result["itemCount"])
         search_result["author"] = None if not has_author else get_item_text(data, 1, default_offset)
 
     elif result_type == "station":
@@ -159,6 +163,13 @@ def parse_search_result(data, search_result_types, result_type, category):
     if result_type in ["song", "album"]:
         search_result["isExplicit"] = nav(data, BADGE_LABEL, True) is not None
 
+    if result_type in ["album"]:
+        search_result["playlistId"] = nav(
+            data,
+            [*PLAY_BUTTON, "playNavigationEndpoint", "watchEndpoint", "playlistId"],
+            True,
+        )
+
     if result_type in ["episode"]:
         flex_item = get_flex_column_item(data, 1)
         has_date = int(len(nav(flex_item, TEXT_RUNS)) > 1)
